@@ -21,8 +21,13 @@ def set_method_to_object(method_func, method_name=None):
     set_method_to_builtin(object, method_func, method_name)
 
 def run_compare(actual, expected = True, func = operator.eq):
-    if actual == types.NoneType:
-        actual = None
+
+    try:            
+        if actual == types.NoneType:
+            actual = None
+    except ValueError, e:
+        pass
+        
     test_case = get_current_test_case()
     test_case.add_assertion()
     if not func(actual, expected):
